@@ -209,9 +209,11 @@ describe 'horizon' do
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           "OVERVIEW_DAYS_RANGE = 1",
+          'DISALLOW_IFRAME_EMBED = True',
         ])
       end
 
+      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with_ensure('directory') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
 
@@ -572,16 +574,16 @@ describe 'horizon' do
       end
     end
 
-    context 'with disallow iframe embed enabled' do
+    context 'with disallow iframe embed disabled' do
       before do
         params.merge!({
-                        :disallow_iframe_embed => true
+                        :disallow_iframe_embed => false
                       })
       end
 
       it 'disallow_iframe_embed is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'HORIZON_CONFIG["disallow_iframe_embed"] = True',
+                                          'DISALLOW_IFRAME_EMBED = False',
                                         ])
       end
     end
@@ -748,6 +750,7 @@ describe 'horizon' do
         when 'Debian'
           if facts[:os_package_type] == 'debian'
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard-apache',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -755,6 +758,7 @@ describe 'horizon' do
             }
           else
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -764,6 +768,7 @@ describe 'horizon' do
         when 'RedHat'
           if facts[:operatingsystem] == 'Fedora'
             { :config_file      => '/etc/openstack-dashboard/local_settings',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard',
               :root_url         => '/dashboard',
               :root_path        => '/usr/share/openstack-dashboard',
@@ -772,6 +777,7 @@ describe 'horizon' do
           else
             if facts[:operatingsystemmajrelease] > '7'
               { :config_file      => '/etc/openstack-dashboard/local_settings',
+                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
                 :package_name     => 'openstack-dashboard',
                 :root_url         => '/dashboard',
                 :root_path        => '/usr/share/openstack-dashboard',
@@ -779,6 +785,7 @@ describe 'horizon' do
               }
             else
               { :config_file      => '/etc/openstack-dashboard/local_settings',
+                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
                 :package_name     => 'openstack-dashboard',
                 :root_url         => '/dashboard',
                 :root_path        => '/usr/share/openstack-dashboard',
